issue

Function issue 

pub fn issue(value: &Value) -> Option<Issue>
Parse GET /v3/issues/{key} (or one element of a search result).

Returns None only when the payload has no key, which means it is not an issue at all.