Shared implementation for the entity commands.
Projects, portfolios and goals are the same endpoint family with a different type name, so they share everything but the word.
Structs
- Fields
- Fields a project, portfolio or goal can be given on the command line.