pub fn render_context(
global: &GlobalArgs,
resolved: Option<&Resolved>,
) -> ContextExpand description
Build the rendering context from flags, profile defaults and the terminal.
pub fn render_context(
global: &GlobalArgs,
resolved: Option<&Resolved>,
) -> ContextBuild the rendering context from flags, profile defaults and the terminal.