pub fn settings(queue: &QueueSettings, ctx: &Context) -> StringExpand description
One queue and the defaults an issue created in it starts with.
pub fn settings(queue: &QueueSettings, ctx: &Context) -> StringOne queue and the defaults an issue created in it starts with.