worklog_search

Function worklog_search 

pub fn worklog_search(entries: &[Worklog], ctx: &Context) -> String
Worklog entries from across the organisation.

Different from worklogs in the one way that matters: the issue is a column, because here it is the only thing that says what the time was for.