pub fn grids(list: &CursorPage<WikiGridRef>, ctx: &Context) -> StringExpand description
The grids on a page: the id wiki grid takes, then when and what.
pub fn grids(list: &CursorPage<WikiGridRef>, ctx: &Context) -> StringThe grids on a page: the id wiki grid takes, then when and what.