pub fn forget(account: &str) -> Result<(), SecretError>Expand description
Remove the stored token. Removing a token that is not there is not an error.
pub fn forget(account: &str) -> Result<(), SecretError>Remove the stored token. Removing a token that is not there is not an error.