store_refresh

Function store_refresh 

pub fn store_refresh(
    account: &str,
    token: Option<&str>,
) -> Result<(), SecretError>
Store the refresh token that came with a token, or remove the one that no longer belongs to it.