pub fn upload_parts(len: usize, size: usize) -> Vec<Range<usize>>
The byte ranges an upload of len bytes is sent in: one part for a file smaller than a part, otherwise parts of size and a shorter last one.
len
size