pub fn worklog_search(entries: &[Worklog], ctx: &Context) -> StringExpand description
Worklog entries from across the organisation.
Different from worklogs in the one way that matters: the issue is a
column, because here it is the only thing that says what the time was for.